@@ -5,7 +5,8 @@ from audig import TocarAudios
 
 class Run:
     def __init__(self):
-        self.run()
+        pass
+        # self.run()
 
     def run(self) -> None:
         # Diretório raiz do curso.
@@ -22,4 +23,4 @@ class Run:
 
 
 if __name__ == "__main__":
-    Run()
+    Run().run()
